==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythgallery/i18n/mythgallery_pt.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="unfinished">Criado em: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="unfinished">Modificado em: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation type="unfinished">Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Largura</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="unfinished">pontos</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished">Altura</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="unfinished">Número de Pontos</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="unfinished">milhões de pontos</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="unfinished">Angulo de Rotação</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="unfinished">graus</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Importar fotos?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Não foi encontrada nenhuma foto</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Directoria com fotos</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Esta directoria tem de existir e o MythGallery tem de ter permissões de leitura.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Directoria para importar fotos</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Estilo de transição</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Tipo de imagem de fundo</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Este é o número de segundos a mostrar cada fotografia no modo contínuo.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>Configurações do MythGallery</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation type="unfinished">Tempo de visualização no modo contínuo</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Introduza uma lista de valores separados por dois pontos. Se o valor for uma directoria, o seu conteúdo serã copiad. Se for um ficheiro executável, este será executado.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Este é o tipo de transição a ser usado ao mudar de fotografia no modo contínuo.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Este é o tipo de imagem de fundo a ser usado na pãgina da fotografia.</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Número de Pontos</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Angulo de Rotação</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>pontos</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>milhões de pontos</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>graus</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Criado em: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Modificado em: </translation>
    </message>
    <message>
        <source>Folder: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythgallery/i18n/mythgallery_pt.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Created: </source>
        <translation type="obsolete">Criado em: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="obsolete">Modificado em: </translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation type="obsolete">Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="obsolete">Largura</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="obsolete">pontos</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="obsolete">Altura</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="obsolete">Número de Pontos</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="obsolete">milhões de pontos</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="obsolete">Angulo de Rotação</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="obsolete">graus</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Import pictures?</source>
        <translation>Importar fotos?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Não foi encontrada nenhuma foto</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Directory &apos;%1&apos; does not exist or is unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery failed to load theme, see console for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected device is no longer available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta Data...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marking...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Marked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Current File or Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting 1 folder, including any subfolders and files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting 1 image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Marked Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting %1 images and folders, including any subfolders and files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving marked images...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying marked images...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Directoria com fotos</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Esta directoria tem de existir e o MythGallery tem de ter permissões de leitura.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Directoria para importar fotos</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Estilo de transição</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Tipo de imagem de fundo</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Este é o número de segundos a mostrar cada fotografia no modo contínuo.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation type="obsolete">Configurações do MythGallery</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation type="unfinished">Tempo de visualização no modo contínuo</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Introduza uma lista de valores separados por dois pontos. Se o valor for uma directoria, o seu conteúdo serã copiad. Se for um ficheiro executável, este será executado.</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Este é o tipo de transição a ser usado ao mudar de fotografia no modo contínuo.</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Este é o tipo de imagem de fundo a ser usado na pãgina da fotografia.</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store thumbnails in image directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, thumbnails are stored in &apos;.thumbcache&apos; directories within the above directory. If cleared, they are stored in your home directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recurse into directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to let the slideshow recurse into sub-directories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overlay caption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the number of seconds to show a caption on top of a full size picture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort order when browsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the sort order for the displayed picture thumbnails.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duration of OpenGL Transition (milliseconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings (Slideshow)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings (General)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Bytes</source>
        <translation type="obsolete">Bytes</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="obsolete">Largura</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="obsolete">Altura</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="obsolete">Número de Pontos</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="obsolete">Angulo de Rotação</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="obsolete">pontos</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="obsolete">milhões de pontos</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="obsolete">graus</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="obsolete">Criado em: </translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="obsolete">Modificado em: </translation>
    </message>
</context>
</TS>
